@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2006 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2025 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: convert-fcrontab.h,v 1.3 2006/01/11 00:54:25 thib Exp thib $ */
 
 #ifndef __CONVERT_FCRONTAB_H__
 #define __CONVERT_FCRONTAB_H__
@@ -29,4 +28,12 @@
 /* We create a .h (even if empty !)  because we have a generic rule
    in Makefile to create .o files which needs the corresponding .h to exist. */
 
-#endif /* __CONVERT_FCRONTAB_H__ */
+#include "global.h"
+
+/* needed for parsing a conf file */
+#include "fcronconf.h"
+
+extern uid_t rootuid;
+extern gid_t rootgid;
+
+#endif                          /* __CONVERT_FCRONTAB_H__ */
