@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2004 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2025 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,20 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: log.h,v 1.7 2004/08/12 09:41:31 thib Exp thib $ */
 
 #ifndef __LOG_H__
 #define __LOG_H__
 
+#ifdef HAVE_LIBPAM
+#include "pam.h"
+#endif
+
+extern char debug_opt;
+extern char *logfile_path;      /* path to a file to log to. Set to NULL to disable logging to a file */
+extern int dosyslog;            /* set to 1 when we log messages to syslog, else 0 */
+
 /* functions prototypes */
+extern void xopenlog(void);
 extern void xcloselog(void);
 extern void explain(char *fmt, ...);
 extern void explain_fd(int fd, char *fmt, ...);
@@ -40,11 +48,11 @@ extern void error_e(char *fmt, ...);
 extern void die(char *fmt, ...);
 extern void die_e(char *fmt, ...);
 #ifdef HAVE_LIBPAM
-extern void error_pame(pam_handle_t *pamh, int pamerrno, char *fmt, ...);
-extern void die_pame(pam_handle_t *pamh, int pamerrno, char *fmt, ...);
+extern void error_pame(pam_handle_t * pamh, int pamerrno, char *fmt, ...);
+extern void die_pame(pam_handle_t * pamh, int pamerrno, char *fmt, ...);
 #endif
 extern void Debug(char *fmt, ...);
 extern void send_msg_fd_debug(int fd, char *fmt, ...);
 extern void send_msg_fd(int fd, char *fmt, ...);
 
-#endif /* __LOG_H__ */
+#endif                          /* __LOG_H__ */
